"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.rpc.status_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class UploadClickConversionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CUSTOMER_ID_FIELD_NUMBER: builtins.int
    CONVERSIONS_FIELD_NUMBER: builtins.int
    PARTIAL_FAILURE_FIELD_NUMBER: builtins.int
    VALIDATE_ONLY_FIELD_NUMBER: builtins.int
    customer_id: typing.Text = ...
    partial_failure: builtins.bool = ...
    validate_only: builtins.bool = ...
    @property
    def conversions(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___ClickConversion
    ]: ...
    def __init__(
        self,
        *,
        customer_id: typing.Text = ...,
        conversions: typing.Optional[typing.Iterable[global___ClickConversion]] = ...,
        partial_failure: builtins.bool = ...,
        validate_only: builtins.bool = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "conversions",
            b"conversions",
            "customer_id",
            b"customer_id",
            "partial_failure",
            b"partial_failure",
            "validate_only",
            b"validate_only",
        ],
    ) -> None: ...

global___UploadClickConversionsRequest = UploadClickConversionsRequest

class UploadClickConversionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PARTIAL_FAILURE_ERROR_FIELD_NUMBER: builtins.int
    RESULTS_FIELD_NUMBER: builtins.int
    @property
    def partial_failure_error(self) -> google.rpc.status_pb2.Status: ...
    @property
    def results(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___ClickConversionResult
    ]: ...
    def __init__(
        self,
        *,
        partial_failure_error: typing.Optional[google.rpc.status_pb2.Status] = ...,
        results: typing.Optional[typing.Iterable[global___ClickConversionResult]] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "partial_failure_error", b"partial_failure_error"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "partial_failure_error", b"partial_failure_error", "results", b"results"
        ],
    ) -> None: ...

global___UploadClickConversionsResponse = UploadClickConversionsResponse

class UploadCallConversionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CUSTOMER_ID_FIELD_NUMBER: builtins.int
    CONVERSIONS_FIELD_NUMBER: builtins.int
    PARTIAL_FAILURE_FIELD_NUMBER: builtins.int
    VALIDATE_ONLY_FIELD_NUMBER: builtins.int
    customer_id: typing.Text = ...
    partial_failure: builtins.bool = ...
    validate_only: builtins.bool = ...
    @property
    def conversions(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___CallConversion
    ]: ...
    def __init__(
        self,
        *,
        customer_id: typing.Text = ...,
        conversions: typing.Optional[typing.Iterable[global___CallConversion]] = ...,
        partial_failure: builtins.bool = ...,
        validate_only: builtins.bool = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "conversions",
            b"conversions",
            "customer_id",
            b"customer_id",
            "partial_failure",
            b"partial_failure",
            "validate_only",
            b"validate_only",
        ],
    ) -> None: ...

global___UploadCallConversionsRequest = UploadCallConversionsRequest

class UploadCallConversionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PARTIAL_FAILURE_ERROR_FIELD_NUMBER: builtins.int
    RESULTS_FIELD_NUMBER: builtins.int
    @property
    def partial_failure_error(self) -> google.rpc.status_pb2.Status: ...
    @property
    def results(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___CallConversionResult
    ]: ...
    def __init__(
        self,
        *,
        partial_failure_error: typing.Optional[google.rpc.status_pb2.Status] = ...,
        results: typing.Optional[typing.Iterable[global___CallConversionResult]] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "partial_failure_error", b"partial_failure_error"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "partial_failure_error", b"partial_failure_error", "results", b"results"
        ],
    ) -> None: ...

global___UploadCallConversionsResponse = UploadCallConversionsResponse

class ClickConversion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    GCLID_FIELD_NUMBER: builtins.int
    CONVERSION_ACTION_FIELD_NUMBER: builtins.int
    CONVERSION_DATE_TIME_FIELD_NUMBER: builtins.int
    CONVERSION_VALUE_FIELD_NUMBER: builtins.int
    CURRENCY_CODE_FIELD_NUMBER: builtins.int
    ORDER_ID_FIELD_NUMBER: builtins.int
    EXTERNAL_ATTRIBUTION_DATA_FIELD_NUMBER: builtins.int
    gclid: typing.Text = ...
    conversion_action: typing.Text = ...
    conversion_date_time: typing.Text = ...
    conversion_value: builtins.float = ...
    currency_code: typing.Text = ...
    order_id: typing.Text = ...
    @property
    def external_attribution_data(self) -> global___ExternalAttributionData: ...
    def __init__(
        self,
        *,
        gclid: typing.Text = ...,
        conversion_action: typing.Text = ...,
        conversion_date_time: typing.Text = ...,
        conversion_value: builtins.float = ...,
        currency_code: typing.Text = ...,
        order_id: typing.Text = ...,
        external_attribution_data: typing.Optional[
            global___ExternalAttributionData
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_conversion_action",
            b"_conversion_action",
            "_conversion_date_time",
            b"_conversion_date_time",
            "_conversion_value",
            b"_conversion_value",
            "_currency_code",
            b"_currency_code",
            "_gclid",
            b"_gclid",
            "_order_id",
            b"_order_id",
            "conversion_action",
            b"conversion_action",
            "conversion_date_time",
            b"conversion_date_time",
            "conversion_value",
            b"conversion_value",
            "currency_code",
            b"currency_code",
            "external_attribution_data",
            b"external_attribution_data",
            "gclid",
            b"gclid",
            "order_id",
            b"order_id",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_conversion_action",
            b"_conversion_action",
            "_conversion_date_time",
            b"_conversion_date_time",
            "_conversion_value",
            b"_conversion_value",
            "_currency_code",
            b"_currency_code",
            "_gclid",
            b"_gclid",
            "_order_id",
            b"_order_id",
            "conversion_action",
            b"conversion_action",
            "conversion_date_time",
            b"conversion_date_time",
            "conversion_value",
            b"conversion_value",
            "currency_code",
            b"currency_code",
            "external_attribution_data",
            b"external_attribution_data",
            "gclid",
            b"gclid",
            "order_id",
            b"order_id",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_conversion_action", b"_conversion_action"
        ],
    ) -> typing_extensions.Literal["conversion_action"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_conversion_date_time", b"_conversion_date_time"
        ],
    ) -> typing_extensions.Literal["conversion_date_time"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_conversion_value", b"_conversion_value"
        ],
    ) -> typing_extensions.Literal["conversion_value"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_currency_code", b"_currency_code"],
    ) -> typing_extensions.Literal["currency_code"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_gclid", b"_gclid"]
    ) -> typing_extensions.Literal["gclid"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_order_id", b"_order_id"]
    ) -> typing_extensions.Literal["order_id"]: ...

global___ClickConversion = ClickConversion

class CallConversion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CALLER_ID_FIELD_NUMBER: builtins.int
    CALL_START_DATE_TIME_FIELD_NUMBER: builtins.int
    CONVERSION_ACTION_FIELD_NUMBER: builtins.int
    CONVERSION_DATE_TIME_FIELD_NUMBER: builtins.int
    CONVERSION_VALUE_FIELD_NUMBER: builtins.int
    CURRENCY_CODE_FIELD_NUMBER: builtins.int
    caller_id: typing.Text = ...
    call_start_date_time: typing.Text = ...
    conversion_action: typing.Text = ...
    conversion_date_time: typing.Text = ...
    conversion_value: builtins.float = ...
    currency_code: typing.Text = ...
    def __init__(
        self,
        *,
        caller_id: typing.Text = ...,
        call_start_date_time: typing.Text = ...,
        conversion_action: typing.Text = ...,
        conversion_date_time: typing.Text = ...,
        conversion_value: builtins.float = ...,
        currency_code: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_call_start_date_time",
            b"_call_start_date_time",
            "_caller_id",
            b"_caller_id",
            "_conversion_action",
            b"_conversion_action",
            "_conversion_date_time",
            b"_conversion_date_time",
            "_conversion_value",
            b"_conversion_value",
            "_currency_code",
            b"_currency_code",
            "call_start_date_time",
            b"call_start_date_time",
            "caller_id",
            b"caller_id",
            "conversion_action",
            b"conversion_action",
            "conversion_date_time",
            b"conversion_date_time",
            "conversion_value",
            b"conversion_value",
            "currency_code",
            b"currency_code",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_call_start_date_time",
            b"_call_start_date_time",
            "_caller_id",
            b"_caller_id",
            "_conversion_action",
            b"_conversion_action",
            "_conversion_date_time",
            b"_conversion_date_time",
            "_conversion_value",
            b"_conversion_value",
            "_currency_code",
            b"_currency_code",
            "call_start_date_time",
            b"call_start_date_time",
            "caller_id",
            b"caller_id",
            "conversion_action",
            b"conversion_action",
            "conversion_date_time",
            b"conversion_date_time",
            "conversion_value",
            b"conversion_value",
            "currency_code",
            b"currency_code",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_call_start_date_time", b"_call_start_date_time"
        ],
    ) -> typing_extensions.Literal["call_start_date_time"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_caller_id", b"_caller_id"]
    ) -> typing_extensions.Literal["caller_id"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_conversion_action", b"_conversion_action"
        ],
    ) -> typing_extensions.Literal["conversion_action"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_conversion_date_time", b"_conversion_date_time"
        ],
    ) -> typing_extensions.Literal["conversion_date_time"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_conversion_value", b"_conversion_value"
        ],
    ) -> typing_extensions.Literal["conversion_value"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_currency_code", b"_currency_code"],
    ) -> typing_extensions.Literal["currency_code"]: ...

global___CallConversion = CallConversion

class ExternalAttributionData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    EXTERNAL_ATTRIBUTION_CREDIT_FIELD_NUMBER: builtins.int
    EXTERNAL_ATTRIBUTION_MODEL_FIELD_NUMBER: builtins.int
    external_attribution_credit: builtins.float = ...
    external_attribution_model: typing.Text = ...
    def __init__(
        self,
        *,
        external_attribution_credit: builtins.float = ...,
        external_attribution_model: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_external_attribution_credit",
            b"_external_attribution_credit",
            "_external_attribution_model",
            b"_external_attribution_model",
            "external_attribution_credit",
            b"external_attribution_credit",
            "external_attribution_model",
            b"external_attribution_model",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_external_attribution_credit",
            b"_external_attribution_credit",
            "_external_attribution_model",
            b"_external_attribution_model",
            "external_attribution_credit",
            b"external_attribution_credit",
            "external_attribution_model",
            b"external_attribution_model",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_external_attribution_credit", b"_external_attribution_credit"
        ],
    ) -> typing_extensions.Literal["external_attribution_credit"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_external_attribution_model", b"_external_attribution_model"
        ],
    ) -> typing_extensions.Literal["external_attribution_model"]: ...

global___ExternalAttributionData = ExternalAttributionData

class ClickConversionResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    GCLID_FIELD_NUMBER: builtins.int
    CONVERSION_ACTION_FIELD_NUMBER: builtins.int
    CONVERSION_DATE_TIME_FIELD_NUMBER: builtins.int
    gclid: typing.Text = ...
    conversion_action: typing.Text = ...
    conversion_date_time: typing.Text = ...
    def __init__(
        self,
        *,
        gclid: typing.Text = ...,
        conversion_action: typing.Text = ...,
        conversion_date_time: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_conversion_action",
            b"_conversion_action",
            "_conversion_date_time",
            b"_conversion_date_time",
            "_gclid",
            b"_gclid",
            "conversion_action",
            b"conversion_action",
            "conversion_date_time",
            b"conversion_date_time",
            "gclid",
            b"gclid",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_conversion_action",
            b"_conversion_action",
            "_conversion_date_time",
            b"_conversion_date_time",
            "_gclid",
            b"_gclid",
            "conversion_action",
            b"conversion_action",
            "conversion_date_time",
            b"conversion_date_time",
            "gclid",
            b"gclid",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_conversion_action", b"_conversion_action"
        ],
    ) -> typing_extensions.Literal["conversion_action"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_conversion_date_time", b"_conversion_date_time"
        ],
    ) -> typing_extensions.Literal["conversion_date_time"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_gclid", b"_gclid"]
    ) -> typing_extensions.Literal["gclid"]: ...

global___ClickConversionResult = ClickConversionResult

class CallConversionResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CALLER_ID_FIELD_NUMBER: builtins.int
    CALL_START_DATE_TIME_FIELD_NUMBER: builtins.int
    CONVERSION_ACTION_FIELD_NUMBER: builtins.int
    CONVERSION_DATE_TIME_FIELD_NUMBER: builtins.int
    caller_id: typing.Text = ...
    call_start_date_time: typing.Text = ...
    conversion_action: typing.Text = ...
    conversion_date_time: typing.Text = ...
    def __init__(
        self,
        *,
        caller_id: typing.Text = ...,
        call_start_date_time: typing.Text = ...,
        conversion_action: typing.Text = ...,
        conversion_date_time: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_call_start_date_time",
            b"_call_start_date_time",
            "_caller_id",
            b"_caller_id",
            "_conversion_action",
            b"_conversion_action",
            "_conversion_date_time",
            b"_conversion_date_time",
            "call_start_date_time",
            b"call_start_date_time",
            "caller_id",
            b"caller_id",
            "conversion_action",
            b"conversion_action",
            "conversion_date_time",
            b"conversion_date_time",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_call_start_date_time",
            b"_call_start_date_time",
            "_caller_id",
            b"_caller_id",
            "_conversion_action",
            b"_conversion_action",
            "_conversion_date_time",
            b"_conversion_date_time",
            "call_start_date_time",
            b"call_start_date_time",
            "caller_id",
            b"caller_id",
            "conversion_action",
            b"conversion_action",
            "conversion_date_time",
            b"conversion_date_time",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_call_start_date_time", b"_call_start_date_time"
        ],
    ) -> typing_extensions.Literal["call_start_date_time"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_caller_id", b"_caller_id"]
    ) -> typing_extensions.Literal["caller_id"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_conversion_action", b"_conversion_action"
        ],
    ) -> typing_extensions.Literal["conversion_action"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_conversion_date_time", b"_conversion_date_time"
        ],
    ) -> typing_extensions.Literal["conversion_date_time"]: ...

global___CallConversionResult = CallConversionResult



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.ad_group_pb2
import grpc

from .ad_group_service_pb2 import *

class AdGroupServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetAdGroup(
        self,
        request: global___GetAdGroupRequest,
    ) -> google.ads.google_ads.v6.proto.resources.ad_group_pb2.AdGroup: ...
    def MutateAdGroups(
        self,
        request: global___MutateAdGroupsRequest,
    ) -> global___MutateAdGroupsResponse: ...

class AdGroupServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetAdGroup(
        self,
        request: global___GetAdGroupRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.ad_group_pb2.AdGroup: ...
    @abc.abstractmethod
    def MutateAdGroups(
        self,
        request: global___MutateAdGroupsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateAdGroupsResponse: ...

def add_AdGroupServiceServicer_to_server(
    servicer: AdGroupServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.enums.call_tracking_display_location_pb2
import google.ads.google_ads.v6.proto.enums.call_type_pb2
import google.ads.google_ads.v6.proto.enums.google_voice_call_status_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CallView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    CALLER_REGION_CODE_FIELD_NUMBER: builtins.int
    CALLER_AREA_CODE_FIELD_NUMBER: builtins.int
    CALL_DURATION_SECONDS_FIELD_NUMBER: builtins.int
    START_CALL_DATE_TIME_FIELD_NUMBER: builtins.int
    END_CALL_DATE_TIME_FIELD_NUMBER: builtins.int
    CALL_TRACKING_DISPLAY_LOCATION_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    CALL_STATUS_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    caller_region_code: typing.Text = ...
    caller_area_code: typing.Text = ...
    call_duration_seconds: builtins.int = ...
    start_call_date_time: typing.Text = ...
    end_call_date_time: typing.Text = ...
    call_tracking_display_location: google.ads.google_ads.v6.proto.enums.call_tracking_display_location_pb2.CallTrackingDisplayLocationEnum.CallTrackingDisplayLocation.V = (
        ...
    )
    type: google.ads.google_ads.v6.proto.enums.call_type_pb2.CallTypeEnum.CallType.V = (
        ...
    )
    call_status: google.ads.google_ads.v6.proto.enums.google_voice_call_status_pb2.GoogleVoiceCallStatusEnum.GoogleVoiceCallStatus.V = (
        ...
    )
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        caller_region_code: typing.Text = ...,
        caller_area_code: typing.Text = ...,
        call_duration_seconds: builtins.int = ...,
        start_call_date_time: typing.Text = ...,
        end_call_date_time: typing.Text = ...,
        call_tracking_display_location: google.ads.google_ads.v6.proto.enums.call_tracking_display_location_pb2.CallTrackingDisplayLocationEnum.CallTrackingDisplayLocation.V = ...,
        type: google.ads.google_ads.v6.proto.enums.call_type_pb2.CallTypeEnum.CallType.V = ...,
        call_status: google.ads.google_ads.v6.proto.enums.google_voice_call_status_pb2.GoogleVoiceCallStatusEnum.GoogleVoiceCallStatus.V = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "call_duration_seconds",
            b"call_duration_seconds",
            "call_status",
            b"call_status",
            "call_tracking_display_location",
            b"call_tracking_display_location",
            "caller_area_code",
            b"caller_area_code",
            "caller_region_code",
            b"caller_region_code",
            "end_call_date_time",
            b"end_call_date_time",
            "resource_name",
            b"resource_name",
            "start_call_date_time",
            b"start_call_date_time",
            "type",
            b"type",
        ],
    ) -> None: ...

global___CallView = CallView



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class UserDataErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _UserDataError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[UserDataError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = UserDataErrorEnum.UserDataError.V(0)
        UNKNOWN = UserDataErrorEnum.UserDataError.V(1)
        OPERATIONS_FOR_CUSTOMER_MATCH_NOT_ALLOWED = UserDataErrorEnum.UserDataError.V(2)
        TOO_MANY_USER_IDENTIFIERS = UserDataErrorEnum.UserDataError.V(3)
        USER_LIST_NOT_APPLICABLE = UserDataErrorEnum.UserDataError.V(4)
    class UserDataError(metaclass=_UserDataError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = UserDataErrorEnum.UserDataError.V(0)
    UNKNOWN = UserDataErrorEnum.UserDataError.V(1)
    OPERATIONS_FOR_CUSTOMER_MATCH_NOT_ALLOWED = UserDataErrorEnum.UserDataError.V(2)
    TOO_MANY_USER_IDENTIFIERS = UserDataErrorEnum.UserDataError.V(3)
    USER_LIST_NOT_APPLICABLE = UserDataErrorEnum.UserDataError.V(4)
    def __init__(
        self,
    ) -> None: ...

global___UserDataErrorEnum = UserDataErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.ad_group_ad_asset_view_pb2
import grpc

from .ad_group_ad_asset_view_service_pb2 import *

class AdGroupAdAssetViewServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetAdGroupAdAssetView(
        self,
        request: global___GetAdGroupAdAssetViewRequest,
    ) -> google.ads.google_ads.v6.proto.resources.ad_group_ad_asset_view_pb2.AdGroupAdAssetView: ...

class AdGroupAdAssetViewServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetAdGroupAdAssetView(
        self,
        request: global___GetAdGroupAdAssetViewRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.ad_group_ad_asset_view_pb2.AdGroupAdAssetView: ...

def add_AdGroupAdAssetViewServiceServicer_to_server(
    servicer: AdGroupAdAssetViewServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MimeTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _MimeType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MimeType.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = MimeTypeEnum.MimeType.V(0)
        UNKNOWN = MimeTypeEnum.MimeType.V(1)
        IMAGE_JPEG = MimeTypeEnum.MimeType.V(2)
        IMAGE_GIF = MimeTypeEnum.MimeType.V(3)
        IMAGE_PNG = MimeTypeEnum.MimeType.V(4)
        FLASH = MimeTypeEnum.MimeType.V(5)
        TEXT_HTML = MimeTypeEnum.MimeType.V(6)
        PDF = MimeTypeEnum.MimeType.V(7)
        MSWORD = MimeTypeEnum.MimeType.V(8)
        MSEXCEL = MimeTypeEnum.MimeType.V(9)
        RTF = MimeTypeEnum.MimeType.V(10)
        AUDIO_WAV = MimeTypeEnum.MimeType.V(11)
        AUDIO_MP3 = MimeTypeEnum.MimeType.V(12)
        HTML5_AD_ZIP = MimeTypeEnum.MimeType.V(13)
    class MimeType(metaclass=_MimeType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = MimeTypeEnum.MimeType.V(0)
    UNKNOWN = MimeTypeEnum.MimeType.V(1)
    IMAGE_JPEG = MimeTypeEnum.MimeType.V(2)
    IMAGE_GIF = MimeTypeEnum.MimeType.V(3)
    IMAGE_PNG = MimeTypeEnum.MimeType.V(4)
    FLASH = MimeTypeEnum.MimeType.V(5)
    TEXT_HTML = MimeTypeEnum.MimeType.V(6)
    PDF = MimeTypeEnum.MimeType.V(7)
    MSWORD = MimeTypeEnum.MimeType.V(8)
    MSEXCEL = MimeTypeEnum.MimeType.V(9)
    RTF = MimeTypeEnum.MimeType.V(10)
    AUDIO_WAV = MimeTypeEnum.MimeType.V(11)
    AUDIO_MP3 = MimeTypeEnum.MimeType.V(12)
    HTML5_AD_ZIP = MimeTypeEnum.MimeType.V(13)
    def __init__(
        self,
    ) -> None: ...

global___MimeTypeEnum = MimeTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v5.proto.resources.campaign_experiment_pb2
import google.longrunning.operations_pb2
import google.protobuf.empty_pb2
import grpc

from .campaign_experiment_service_pb2 import *

class CampaignExperimentServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetCampaignExperiment(
        self,
        request: global___GetCampaignExperimentRequest,
    ) -> google.ads.google_ads.v5.proto.resources.campaign_experiment_pb2.CampaignExperiment: ...
    def CreateCampaignExperiment(
        self,
        request: global___CreateCampaignExperimentRequest,
    ) -> google.longrunning.operations_pb2.Operation: ...
    def MutateCampaignExperiments(
        self,
        request: global___MutateCampaignExperimentsRequest,
    ) -> global___MutateCampaignExperimentsResponse: ...
    def GraduateCampaignExperiment(
        self,
        request: global___GraduateCampaignExperimentRequest,
    ) -> global___GraduateCampaignExperimentResponse: ...
    def PromoteCampaignExperiment(
        self,
        request: global___PromoteCampaignExperimentRequest,
    ) -> google.longrunning.operations_pb2.Operation: ...
    def EndCampaignExperiment(
        self,
        request: global___EndCampaignExperimentRequest,
    ) -> google.protobuf.empty_pb2.Empty: ...
    def ListCampaignExperimentAsyncErrors(
        self,
        request: global___ListCampaignExperimentAsyncErrorsRequest,
    ) -> global___ListCampaignExperimentAsyncErrorsResponse: ...

class CampaignExperimentServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetCampaignExperiment(
        self,
        request: global___GetCampaignExperimentRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v5.proto.resources.campaign_experiment_pb2.CampaignExperiment: ...
    @abc.abstractmethod
    def CreateCampaignExperiment(
        self,
        request: global___CreateCampaignExperimentRequest,
        context: grpc.ServicerContext,
    ) -> google.longrunning.operations_pb2.Operation: ...
    @abc.abstractmethod
    def MutateCampaignExperiments(
        self,
        request: global___MutateCampaignExperimentsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateCampaignExperimentsResponse: ...
    @abc.abstractmethod
    def GraduateCampaignExperiment(
        self,
        request: global___GraduateCampaignExperimentRequest,
        context: grpc.ServicerContext,
    ) -> global___GraduateCampaignExperimentResponse: ...
    @abc.abstractmethod
    def PromoteCampaignExperiment(
        self,
        request: global___PromoteCampaignExperimentRequest,
        context: grpc.ServicerContext,
    ) -> google.longrunning.operations_pb2.Operation: ...
    @abc.abstractmethod
    def EndCampaignExperiment(
        self,
        request: global___EndCampaignExperimentRequest,
        context: grpc.ServicerContext,
    ) -> google.protobuf.empty_pb2.Empty: ...
    @abc.abstractmethod
    def ListCampaignExperimentAsyncErrors(
        self,
        request: global___ListCampaignExperimentAsyncErrorsRequest,
        context: grpc.ServicerContext,
    ) -> global___ListCampaignExperimentAsyncErrorsResponse: ...

def add_CampaignExperimentServiceServicer_to_server(
    servicer: CampaignExperimentServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .invoice_service_pb2 import *

class InvoiceServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def ListInvoices(
        self,
        request: global___ListInvoicesRequest,
    ) -> global___ListInvoicesResponse: ...

class InvoiceServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def ListInvoices(
        self,
        request: global___ListInvoicesRequest,
        context: grpc.ServicerContext,
    ) -> global___ListInvoicesResponse: ...

def add_InvoiceServiceServicer_to_server(
    servicer: InvoiceServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v5.proto.resources.operating_system_version_constant_pb2
import grpc

from .operating_system_version_constant_service_pb2 import *

class OperatingSystemVersionConstantServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetOperatingSystemVersionConstant(
        self,
        request: global___GetOperatingSystemVersionConstantRequest,
    ) -> google.ads.google_ads.v5.proto.resources.operating_system_version_constant_pb2.OperatingSystemVersionConstant: ...

class OperatingSystemVersionConstantServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetOperatingSystemVersionConstant(
        self,
        request: global___GetOperatingSystemVersionConstantRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v5.proto.resources.operating_system_version_constant_pb2.OperatingSystemVersionConstant: ...

def add_OperatingSystemVersionConstantServiceServicer_to_server(
    servicer: OperatingSystemVersionConstantServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AccountBudgetProposalErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AccountBudgetProposalError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            AccountBudgetProposalError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(0)
        UNKNOWN = AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(1)
        FIELD_MASK_NOT_ALLOWED = (
            AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(2)
        )
        IMMUTABLE_FIELD = AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(3)
        REQUIRED_FIELD_MISSING = (
            AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(4)
        )
        CANNOT_CANCEL_APPROVED_PROPOSAL = (
            AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(5)
        )
        CANNOT_REMOVE_UNAPPROVED_BUDGET = (
            AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(6)
        )
        CANNOT_REMOVE_RUNNING_BUDGET = (
            AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(7)
        )
        CANNOT_END_UNAPPROVED_BUDGET = (
            AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(8)
        )
        CANNOT_END_INACTIVE_BUDGET = (
            AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(9)
        )
        BUDGET_NAME_REQUIRED = (
            AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(10)
        )
        CANNOT_UPDATE_OLD_BUDGET = (
            AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(11)
        )
        CANNOT_END_IN_PAST = (
            AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(12)
        )
        CANNOT_EXTEND_END_TIME = (
            AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(13)
        )
        PURCHASE_ORDER_NUMBER_REQUIRED = (
            AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(14)
        )
        PENDING_UPDATE_PROPOSAL_EXISTS = (
            AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(15)
        )
        MULTIPLE_BUDGETS_NOT_ALLOWED_FOR_UNAPPROVED_BILLING_SETUP = (
            AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(16)
        )
        CANNOT_UPDATE_START_TIME_FOR_STARTED_BUDGET = (
            AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(17)
        )
        SPENDING_LIMIT_LOWER_THAN_ACCRUED_COST_NOT_ALLOWED = (
            AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(18)
        )
        UPDATE_IS_NO_OP = AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(
            19
        )
        END_TIME_MUST_FOLLOW_START_TIME = (
            AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(20)
        )
        BUDGET_DATE_RANGE_INCOMPATIBLE_WITH_BILLING_SETUP = (
            AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(21)
        )
        NOT_AUTHORIZED = AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(22)
        INVALID_BILLING_SETUP = (
            AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(23)
        )
        OVERLAPS_EXISTING_BUDGET = (
            AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(24)
        )
        CANNOT_CREATE_BUDGET_THROUGH_API = (
            AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(25)
        )
    class AccountBudgetProposalError(metaclass=_AccountBudgetProposalError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(0)
    UNKNOWN = AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(1)
    FIELD_MASK_NOT_ALLOWED = (
        AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(2)
    )
    IMMUTABLE_FIELD = AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(3)
    REQUIRED_FIELD_MISSING = (
        AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(4)
    )
    CANNOT_CANCEL_APPROVED_PROPOSAL = (
        AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(5)
    )
    CANNOT_REMOVE_UNAPPROVED_BUDGET = (
        AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(6)
    )
    CANNOT_REMOVE_RUNNING_BUDGET = (
        AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(7)
    )
    CANNOT_END_UNAPPROVED_BUDGET = (
        AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(8)
    )
    CANNOT_END_INACTIVE_BUDGET = (
        AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(9)
    )
    BUDGET_NAME_REQUIRED = AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(
        10
    )
    CANNOT_UPDATE_OLD_BUDGET = (
        AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(11)
    )
    CANNOT_END_IN_PAST = AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(12)
    CANNOT_EXTEND_END_TIME = (
        AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(13)
    )
    PURCHASE_ORDER_NUMBER_REQUIRED = (
        AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(14)
    )
    PENDING_UPDATE_PROPOSAL_EXISTS = (
        AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(15)
    )
    MULTIPLE_BUDGETS_NOT_ALLOWED_FOR_UNAPPROVED_BILLING_SETUP = (
        AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(16)
    )
    CANNOT_UPDATE_START_TIME_FOR_STARTED_BUDGET = (
        AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(17)
    )
    SPENDING_LIMIT_LOWER_THAN_ACCRUED_COST_NOT_ALLOWED = (
        AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(18)
    )
    UPDATE_IS_NO_OP = AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(19)
    END_TIME_MUST_FOLLOW_START_TIME = (
        AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(20)
    )
    BUDGET_DATE_RANGE_INCOMPATIBLE_WITH_BILLING_SETUP = (
        AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(21)
    )
    NOT_AUTHORIZED = AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(22)
    INVALID_BILLING_SETUP = AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(
        23
    )
    OVERLAPS_EXISTING_BUDGET = (
        AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(24)
    )
    CANNOT_CREATE_BUDGET_THROUGH_API = (
        AccountBudgetProposalErrorEnum.AccountBudgetProposalError.V(25)
    )
    def __init__(
        self,
    ) -> None: ...

global___AccountBudgetProposalErrorEnum = AccountBudgetProposalErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ChangeEventErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ChangeEventError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ChangeEventError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ChangeEventErrorEnum.ChangeEventError.V(0)
        UNKNOWN = ChangeEventErrorEnum.ChangeEventError.V(1)
        START_DATE_TOO_OLD = ChangeEventErrorEnum.ChangeEventError.V(2)
        CHANGE_DATE_RANGE_INFINITE = ChangeEventErrorEnum.ChangeEventError.V(3)
        CHANGE_DATE_RANGE_NEGATIVE = ChangeEventErrorEnum.ChangeEventError.V(4)
        LIMIT_NOT_SPECIFIED = ChangeEventErrorEnum.ChangeEventError.V(5)
        INVALID_LIMIT_CLAUSE = ChangeEventErrorEnum.ChangeEventError.V(6)
    class ChangeEventError(metaclass=_ChangeEventError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ChangeEventErrorEnum.ChangeEventError.V(0)
    UNKNOWN = ChangeEventErrorEnum.ChangeEventError.V(1)
    START_DATE_TOO_OLD = ChangeEventErrorEnum.ChangeEventError.V(2)
    CHANGE_DATE_RANGE_INFINITE = ChangeEventErrorEnum.ChangeEventError.V(3)
    CHANGE_DATE_RANGE_NEGATIVE = ChangeEventErrorEnum.ChangeEventError.V(4)
    LIMIT_NOT_SPECIFIED = ChangeEventErrorEnum.ChangeEventError.V(5)
    INVALID_LIMIT_CLAUSE = ChangeEventErrorEnum.ChangeEventError.V(6)
    def __init__(
        self,
    ) -> None: ...

global___ChangeEventErrorEnum = ChangeEventErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.enums.access_invitation_status_pb2
import google.ads.google_ads.v6.proto.enums.access_role_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CustomerUserAccessInvitation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    INVITATION_ID_FIELD_NUMBER: builtins.int
    ACCESS_ROLE_FIELD_NUMBER: builtins.int
    EMAIL_ADDRESS_FIELD_NUMBER: builtins.int
    CREATION_DATE_TIME_FIELD_NUMBER: builtins.int
    INVITATION_STATUS_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    invitation_id: builtins.int = ...
    access_role: google.ads.google_ads.v6.proto.enums.access_role_pb2.AccessRoleEnum.AccessRole.V = (
        ...
    )
    email_address: typing.Text = ...
    creation_date_time: typing.Text = ...
    invitation_status: google.ads.google_ads.v6.proto.enums.access_invitation_status_pb2.AccessInvitationStatusEnum.AccessInvitationStatus.V = (
        ...
    )
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        invitation_id: builtins.int = ...,
        access_role: google.ads.google_ads.v6.proto.enums.access_role_pb2.AccessRoleEnum.AccessRole.V = ...,
        email_address: typing.Text = ...,
        creation_date_time: typing.Text = ...,
        invitation_status: google.ads.google_ads.v6.proto.enums.access_invitation_status_pb2.AccessInvitationStatusEnum.AccessInvitationStatus.V = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "access_role",
            b"access_role",
            "creation_date_time",
            b"creation_date_time",
            "email_address",
            b"email_address",
            "invitation_id",
            b"invitation_id",
            "invitation_status",
            b"invitation_status",
            "resource_name",
            b"resource_name",
        ],
    ) -> None: ...

global___CustomerUserAccessInvitation = CustomerUserAccessInvitation



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class DayOfWeekEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _DayOfWeek(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[DayOfWeek.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = DayOfWeekEnum.DayOfWeek.V(0)
        UNKNOWN = DayOfWeekEnum.DayOfWeek.V(1)
        MONDAY = DayOfWeekEnum.DayOfWeek.V(2)
        TUESDAY = DayOfWeekEnum.DayOfWeek.V(3)
        WEDNESDAY = DayOfWeekEnum.DayOfWeek.V(4)
        THURSDAY = DayOfWeekEnum.DayOfWeek.V(5)
        FRIDAY = DayOfWeekEnum.DayOfWeek.V(6)
        SATURDAY = DayOfWeekEnum.DayOfWeek.V(7)
        SUNDAY = DayOfWeekEnum.DayOfWeek.V(8)
    class DayOfWeek(metaclass=_DayOfWeek):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = DayOfWeekEnum.DayOfWeek.V(0)
    UNKNOWN = DayOfWeekEnum.DayOfWeek.V(1)
    MONDAY = DayOfWeekEnum.DayOfWeek.V(2)
    TUESDAY = DayOfWeekEnum.DayOfWeek.V(3)
    WEDNESDAY = DayOfWeekEnum.DayOfWeek.V(4)
    THURSDAY = DayOfWeekEnum.DayOfWeek.V(5)
    FRIDAY = DayOfWeekEnum.DayOfWeek.V(6)
    SATURDAY = DayOfWeekEnum.DayOfWeek.V(7)
    SUNDAY = DayOfWeekEnum.DayOfWeek.V(8)
    def __init__(
        self,
    ) -> None: ...

global___DayOfWeekEnum = DayOfWeekEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v4.proto.resources.search_term_view_pb2
import grpc

from .search_term_view_service_pb2 import *

class SearchTermViewServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetSearchTermView(
        self,
        request: global___GetSearchTermViewRequest,
    ) -> google.ads.google_ads.v4.proto.resources.search_term_view_pb2.SearchTermView: ...

class SearchTermViewServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetSearchTermView(
        self,
        request: global___GetSearchTermViewRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v4.proto.resources.search_term_view_pb2.SearchTermView: ...

def add_SearchTermViewServiceServicer_to_server(
    servicer: SearchTermViewServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class IncomeRangeTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _IncomeRangeType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[IncomeRangeType.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = IncomeRangeTypeEnum.IncomeRangeType.V(0)
        UNKNOWN = IncomeRangeTypeEnum.IncomeRangeType.V(1)
        INCOME_RANGE_0_50 = IncomeRangeTypeEnum.IncomeRangeType.V(510001)
        INCOME_RANGE_50_60 = IncomeRangeTypeEnum.IncomeRangeType.V(510002)
        INCOME_RANGE_60_70 = IncomeRangeTypeEnum.IncomeRangeType.V(510003)
        INCOME_RANGE_70_80 = IncomeRangeTypeEnum.IncomeRangeType.V(510004)
        INCOME_RANGE_80_90 = IncomeRangeTypeEnum.IncomeRangeType.V(510005)
        INCOME_RANGE_90_UP = IncomeRangeTypeEnum.IncomeRangeType.V(510006)
        INCOME_RANGE_UNDETERMINED = IncomeRangeTypeEnum.IncomeRangeType.V(510000)
    class IncomeRangeType(metaclass=_IncomeRangeType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = IncomeRangeTypeEnum.IncomeRangeType.V(0)
    UNKNOWN = IncomeRangeTypeEnum.IncomeRangeType.V(1)
    INCOME_RANGE_0_50 = IncomeRangeTypeEnum.IncomeRangeType.V(510001)
    INCOME_RANGE_50_60 = IncomeRangeTypeEnum.IncomeRangeType.V(510002)
    INCOME_RANGE_60_70 = IncomeRangeTypeEnum.IncomeRangeType.V(510003)
    INCOME_RANGE_70_80 = IncomeRangeTypeEnum.IncomeRangeType.V(510004)
    INCOME_RANGE_80_90 = IncomeRangeTypeEnum.IncomeRangeType.V(510005)
    INCOME_RANGE_90_UP = IncomeRangeTypeEnum.IncomeRangeType.V(510006)
    INCOME_RANGE_UNDETERMINED = IncomeRangeTypeEnum.IncomeRangeType.V(510000)
    def __init__(
        self,
    ) -> None: ...

global___IncomeRangeTypeEnum = IncomeRangeTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ConversionOrAdjustmentLagBucketEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ConversionOrAdjustmentLagBucket(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ConversionOrAdjustmentLagBucket.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(0)
        )
        UNKNOWN = ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(
            1
        )
        CONVERSION_LESS_THAN_ONE_DAY = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(2)
        )
        CONVERSION_ONE_TO_TWO_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(3)
        )
        CONVERSION_TWO_TO_THREE_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(4)
        )
        CONVERSION_THREE_TO_FOUR_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(5)
        )
        CONVERSION_FOUR_TO_FIVE_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(6)
        )
        CONVERSION_FIVE_TO_SIX_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(7)
        )
        CONVERSION_SIX_TO_SEVEN_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(8)
        )
        CONVERSION_SEVEN_TO_EIGHT_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(9)
        )
        CONVERSION_EIGHT_TO_NINE_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(10)
        )
        CONVERSION_NINE_TO_TEN_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(11)
        )
        CONVERSION_TEN_TO_ELEVEN_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(12)
        )
        CONVERSION_ELEVEN_TO_TWELVE_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(13)
        )
        CONVERSION_TWELVE_TO_THIRTEEN_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(14)
        )
        CONVERSION_THIRTEEN_TO_FOURTEEN_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(15)
        )
        CONVERSION_FOURTEEN_TO_TWENTY_ONE_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(16)
        )
        CONVERSION_TWENTY_ONE_TO_THIRTY_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(17)
        )
        CONVERSION_THIRTY_TO_FORTY_FIVE_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(18)
        )
        CONVERSION_FORTY_FIVE_TO_SIXTY_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(19)
        )
        CONVERSION_SIXTY_TO_NINETY_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(20)
        )
        ADJUSTMENT_LESS_THAN_ONE_DAY = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(21)
        )
        ADJUSTMENT_ONE_TO_TWO_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(22)
        )
        ADJUSTMENT_TWO_TO_THREE_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(23)
        )
        ADJUSTMENT_THREE_TO_FOUR_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(24)
        )
        ADJUSTMENT_FOUR_TO_FIVE_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(25)
        )
        ADJUSTMENT_FIVE_TO_SIX_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(26)
        )
        ADJUSTMENT_SIX_TO_SEVEN_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(27)
        )
        ADJUSTMENT_SEVEN_TO_EIGHT_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(28)
        )
        ADJUSTMENT_EIGHT_TO_NINE_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(29)
        )
        ADJUSTMENT_NINE_TO_TEN_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(30)
        )
        ADJUSTMENT_TEN_TO_ELEVEN_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(31)
        )
        ADJUSTMENT_ELEVEN_TO_TWELVE_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(32)
        )
        ADJUSTMENT_TWELVE_TO_THIRTEEN_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(33)
        )
        ADJUSTMENT_THIRTEEN_TO_FOURTEEN_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(34)
        )
        ADJUSTMENT_FOURTEEN_TO_TWENTY_ONE_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(35)
        )
        ADJUSTMENT_TWENTY_ONE_TO_THIRTY_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(36)
        )
        ADJUSTMENT_THIRTY_TO_FORTY_FIVE_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(37)
        )
        ADJUSTMENT_FORTY_FIVE_TO_SIXTY_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(38)
        )
        ADJUSTMENT_SIXTY_TO_NINETY_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(39)
        )
        ADJUSTMENT_NINETY_TO_ONE_HUNDRED_AND_FORTY_FIVE_DAYS = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(40)
        )
        CONVERSION_UNKNOWN = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(41)
        )
        ADJUSTMENT_UNKNOWN = (
            ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(42)
        )
    class ConversionOrAdjustmentLagBucket(metaclass=_ConversionOrAdjustmentLagBucket):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(
        0
    )
    UNKNOWN = ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(1)
    CONVERSION_LESS_THAN_ONE_DAY = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(2)
    )
    CONVERSION_ONE_TO_TWO_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(3)
    )
    CONVERSION_TWO_TO_THREE_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(4)
    )
    CONVERSION_THREE_TO_FOUR_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(5)
    )
    CONVERSION_FOUR_TO_FIVE_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(6)
    )
    CONVERSION_FIVE_TO_SIX_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(7)
    )
    CONVERSION_SIX_TO_SEVEN_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(8)
    )
    CONVERSION_SEVEN_TO_EIGHT_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(9)
    )
    CONVERSION_EIGHT_TO_NINE_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(10)
    )
    CONVERSION_NINE_TO_TEN_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(11)
    )
    CONVERSION_TEN_TO_ELEVEN_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(12)
    )
    CONVERSION_ELEVEN_TO_TWELVE_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(13)
    )
    CONVERSION_TWELVE_TO_THIRTEEN_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(14)
    )
    CONVERSION_THIRTEEN_TO_FOURTEEN_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(15)
    )
    CONVERSION_FOURTEEN_TO_TWENTY_ONE_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(16)
    )
    CONVERSION_TWENTY_ONE_TO_THIRTY_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(17)
    )
    CONVERSION_THIRTY_TO_FORTY_FIVE_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(18)
    )
    CONVERSION_FORTY_FIVE_TO_SIXTY_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(19)
    )
    CONVERSION_SIXTY_TO_NINETY_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(20)
    )
    ADJUSTMENT_LESS_THAN_ONE_DAY = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(21)
    )
    ADJUSTMENT_ONE_TO_TWO_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(22)
    )
    ADJUSTMENT_TWO_TO_THREE_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(23)
    )
    ADJUSTMENT_THREE_TO_FOUR_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(24)
    )
    ADJUSTMENT_FOUR_TO_FIVE_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(25)
    )
    ADJUSTMENT_FIVE_TO_SIX_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(26)
    )
    ADJUSTMENT_SIX_TO_SEVEN_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(27)
    )
    ADJUSTMENT_SEVEN_TO_EIGHT_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(28)
    )
    ADJUSTMENT_EIGHT_TO_NINE_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(29)
    )
    ADJUSTMENT_NINE_TO_TEN_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(30)
    )
    ADJUSTMENT_TEN_TO_ELEVEN_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(31)
    )
    ADJUSTMENT_ELEVEN_TO_TWELVE_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(32)
    )
    ADJUSTMENT_TWELVE_TO_THIRTEEN_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(33)
    )
    ADJUSTMENT_THIRTEEN_TO_FOURTEEN_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(34)
    )
    ADJUSTMENT_FOURTEEN_TO_TWENTY_ONE_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(35)
    )
    ADJUSTMENT_TWENTY_ONE_TO_THIRTY_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(36)
    )
    ADJUSTMENT_THIRTY_TO_FORTY_FIVE_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(37)
    )
    ADJUSTMENT_FORTY_FIVE_TO_SIXTY_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(38)
    )
    ADJUSTMENT_SIXTY_TO_NINETY_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(39)
    )
    ADJUSTMENT_NINETY_TO_ONE_HUNDRED_AND_FORTY_FIVE_DAYS = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(40)
    )
    CONVERSION_UNKNOWN = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(41)
    )
    ADJUSTMENT_UNKNOWN = (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V(42)
    )
    def __init__(
        self,
    ) -> None: ...

global___ConversionOrAdjustmentLagBucketEnum = ConversionOrAdjustmentLagBucketEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.enums.target_impression_share_location_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Commission(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    COMMISSION_RATE_MICROS_FIELD_NUMBER: builtins.int
    commission_rate_micros: builtins.int = ...
    def __init__(
        self,
        *,
        commission_rate_micros: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_commission_rate_micros",
            b"_commission_rate_micros",
            "commission_rate_micros",
            b"commission_rate_micros",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_commission_rate_micros",
            b"_commission_rate_micros",
            "commission_rate_micros",
            b"commission_rate_micros",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_commission_rate_micros", b"_commission_rate_micros"
        ],
    ) -> typing_extensions.Literal["commission_rate_micros"]: ...

global___Commission = Commission

class EnhancedCpc(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    def __init__(
        self,
    ) -> None: ...

global___EnhancedCpc = EnhancedCpc

class ManualCpc(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ENHANCED_CPC_ENABLED_FIELD_NUMBER: builtins.int
    enhanced_cpc_enabled: builtins.bool = ...
    def __init__(
        self,
        *,
        enhanced_cpc_enabled: builtins.bool = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_enhanced_cpc_enabled",
            b"_enhanced_cpc_enabled",
            "enhanced_cpc_enabled",
            b"enhanced_cpc_enabled",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_enhanced_cpc_enabled",
            b"_enhanced_cpc_enabled",
            "enhanced_cpc_enabled",
            b"enhanced_cpc_enabled",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_enhanced_cpc_enabled", b"_enhanced_cpc_enabled"
        ],
    ) -> typing_extensions.Literal["enhanced_cpc_enabled"]: ...

global___ManualCpc = ManualCpc

class ManualCpm(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    def __init__(
        self,
    ) -> None: ...

global___ManualCpm = ManualCpm

class ManualCpv(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    def __init__(
        self,
    ) -> None: ...

global___ManualCpv = ManualCpv

class MaximizeConversions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    def __init__(
        self,
    ) -> None: ...

global___MaximizeConversions = MaximizeConversions

class MaximizeConversionValue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TARGET_ROAS_FIELD_NUMBER: builtins.int
    target_roas: builtins.float = ...
    def __init__(
        self,
        *,
        target_roas: builtins.float = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_target_roas", b"_target_roas", "target_roas", b"target_roas"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_target_roas", b"_target_roas", "target_roas", b"target_roas"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_target_roas", b"_target_roas"]
    ) -> typing_extensions.Literal["target_roas"]: ...

global___MaximizeConversionValue = MaximizeConversionValue

class TargetCpa(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TARGET_CPA_MICROS_FIELD_NUMBER: builtins.int
    CPC_BID_CEILING_MICROS_FIELD_NUMBER: builtins.int
    CPC_BID_FLOOR_MICROS_FIELD_NUMBER: builtins.int
    target_cpa_micros: builtins.int = ...
    cpc_bid_ceiling_micros: builtins.int = ...
    cpc_bid_floor_micros: builtins.int = ...
    def __init__(
        self,
        *,
        target_cpa_micros: builtins.int = ...,
        cpc_bid_ceiling_micros: builtins.int = ...,
        cpc_bid_floor_micros: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_cpc_bid_ceiling_micros",
            b"_cpc_bid_ceiling_micros",
            "_cpc_bid_floor_micros",
            b"_cpc_bid_floor_micros",
            "_target_cpa_micros",
            b"_target_cpa_micros",
            "cpc_bid_ceiling_micros",
            b"cpc_bid_ceiling_micros",
            "cpc_bid_floor_micros",
            b"cpc_bid_floor_micros",
            "target_cpa_micros",
            b"target_cpa_micros",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_cpc_bid_ceiling_micros",
            b"_cpc_bid_ceiling_micros",
            "_cpc_bid_floor_micros",
            b"_cpc_bid_floor_micros",
            "_target_cpa_micros",
            b"_target_cpa_micros",
            "cpc_bid_ceiling_micros",
            b"cpc_bid_ceiling_micros",
            "cpc_bid_floor_micros",
            b"cpc_bid_floor_micros",
            "target_cpa_micros",
            b"target_cpa_micros",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_cpc_bid_ceiling_micros", b"_cpc_bid_ceiling_micros"
        ],
    ) -> typing_extensions.Literal["cpc_bid_ceiling_micros"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_cpc_bid_floor_micros", b"_cpc_bid_floor_micros"
        ],
    ) -> typing_extensions.Literal["cpc_bid_floor_micros"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_target_cpa_micros", b"_target_cpa_micros"
        ],
    ) -> typing_extensions.Literal["target_cpa_micros"]: ...

global___TargetCpa = TargetCpa

class TargetCpm(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    def __init__(
        self,
    ) -> None: ...

global___TargetCpm = TargetCpm

class TargetImpressionShare(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    LOCATION_FIELD_NUMBER: builtins.int
    LOCATION_FRACTION_MICROS_FIELD_NUMBER: builtins.int
    CPC_BID_CEILING_MICROS_FIELD_NUMBER: builtins.int
    location: google.ads.google_ads.v5.proto.enums.target_impression_share_location_pb2.TargetImpressionShareLocationEnum.TargetImpressionShareLocation.V = (
        ...
    )
    location_fraction_micros: builtins.int = ...
    cpc_bid_ceiling_micros: builtins.int = ...
    def __init__(
        self,
        *,
        location: google.ads.google_ads.v5.proto.enums.target_impression_share_location_pb2.TargetImpressionShareLocationEnum.TargetImpressionShareLocation.V = ...,
        location_fraction_micros: builtins.int = ...,
        cpc_bid_ceiling_micros: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_cpc_bid_ceiling_micros",
            b"_cpc_bid_ceiling_micros",
            "_location_fraction_micros",
            b"_location_fraction_micros",
            "cpc_bid_ceiling_micros",
            b"cpc_bid_ceiling_micros",
            "location_fraction_micros",
            b"location_fraction_micros",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_cpc_bid_ceiling_micros",
            b"_cpc_bid_ceiling_micros",
            "_location_fraction_micros",
            b"_location_fraction_micros",
            "cpc_bid_ceiling_micros",
            b"cpc_bid_ceiling_micros",
            "location",
            b"location",
            "location_fraction_micros",
            b"location_fraction_micros",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_cpc_bid_ceiling_micros", b"_cpc_bid_ceiling_micros"
        ],
    ) -> typing_extensions.Literal["cpc_bid_ceiling_micros"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_location_fraction_micros", b"_location_fraction_micros"
        ],
    ) -> typing_extensions.Literal["location_fraction_micros"]: ...

global___TargetImpressionShare = TargetImpressionShare

class TargetRoas(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TARGET_ROAS_FIELD_NUMBER: builtins.int
    CPC_BID_CEILING_MICROS_FIELD_NUMBER: builtins.int
    CPC_BID_FLOOR_MICROS_FIELD_NUMBER: builtins.int
    target_roas: builtins.float = ...
    cpc_bid_ceiling_micros: builtins.int = ...
    cpc_bid_floor_micros: builtins.int = ...
    def __init__(
        self,
        *,
        target_roas: builtins.float = ...,
        cpc_bid_ceiling_micros: builtins.int = ...,
        cpc_bid_floor_micros: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_cpc_bid_ceiling_micros",
            b"_cpc_bid_ceiling_micros",
            "_cpc_bid_floor_micros",
            b"_cpc_bid_floor_micros",
            "_target_roas",
            b"_target_roas",
            "cpc_bid_ceiling_micros",
            b"cpc_bid_ceiling_micros",
            "cpc_bid_floor_micros",
            b"cpc_bid_floor_micros",
            "target_roas",
            b"target_roas",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_cpc_bid_ceiling_micros",
            b"_cpc_bid_ceiling_micros",
            "_cpc_bid_floor_micros",
            b"_cpc_bid_floor_micros",
            "_target_roas",
            b"_target_roas",
            "cpc_bid_ceiling_micros",
            b"cpc_bid_ceiling_micros",
            "cpc_bid_floor_micros",
            b"cpc_bid_floor_micros",
            "target_roas",
            b"target_roas",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_cpc_bid_ceiling_micros", b"_cpc_bid_ceiling_micros"
        ],
    ) -> typing_extensions.Literal["cpc_bid_ceiling_micros"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_cpc_bid_floor_micros", b"_cpc_bid_floor_micros"
        ],
    ) -> typing_extensions.Literal["cpc_bid_floor_micros"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_target_roas", b"_target_roas"]
    ) -> typing_extensions.Literal["target_roas"]: ...

global___TargetRoas = TargetRoas

class TargetSpend(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TARGET_SPEND_MICROS_FIELD_NUMBER: builtins.int
    CPC_BID_CEILING_MICROS_FIELD_NUMBER: builtins.int
    target_spend_micros: builtins.int = ...
    cpc_bid_ceiling_micros: builtins.int = ...
    def __init__(
        self,
        *,
        target_spend_micros: builtins.int = ...,
        cpc_bid_ceiling_micros: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_cpc_bid_ceiling_micros",
            b"_cpc_bid_ceiling_micros",
            "_target_spend_micros",
            b"_target_spend_micros",
            "cpc_bid_ceiling_micros",
            b"cpc_bid_ceiling_micros",
            "target_spend_micros",
            b"target_spend_micros",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_cpc_bid_ceiling_micros",
            b"_cpc_bid_ceiling_micros",
            "_target_spend_micros",
            b"_target_spend_micros",
            "cpc_bid_ceiling_micros",
            b"cpc_bid_ceiling_micros",
            "target_spend_micros",
            b"target_spend_micros",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_cpc_bid_ceiling_micros", b"_cpc_bid_ceiling_micros"
        ],
    ) -> typing_extensions.Literal["cpc_bid_ceiling_micros"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_target_spend_micros", b"_target_spend_micros"
        ],
    ) -> typing_extensions.Literal["target_spend_micros"]: ...

global___TargetSpend = TargetSpend

class PercentCpc(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CPC_BID_CEILING_MICROS_FIELD_NUMBER: builtins.int
    ENHANCED_CPC_ENABLED_FIELD_NUMBER: builtins.int
    cpc_bid_ceiling_micros: builtins.int = ...
    enhanced_cpc_enabled: builtins.bool = ...
    def __init__(
        self,
        *,
        cpc_bid_ceiling_micros: builtins.int = ...,
        enhanced_cpc_enabled: builtins.bool = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_cpc_bid_ceiling_micros",
            b"_cpc_bid_ceiling_micros",
            "_enhanced_cpc_enabled",
            b"_enhanced_cpc_enabled",
            "cpc_bid_ceiling_micros",
            b"cpc_bid_ceiling_micros",
            "enhanced_cpc_enabled",
            b"enhanced_cpc_enabled",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_cpc_bid_ceiling_micros",
            b"_cpc_bid_ceiling_micros",
            "_enhanced_cpc_enabled",
            b"_enhanced_cpc_enabled",
            "cpc_bid_ceiling_micros",
            b"cpc_bid_ceiling_micros",
            "enhanced_cpc_enabled",
            b"enhanced_cpc_enabled",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_cpc_bid_ceiling_micros", b"_cpc_bid_ceiling_micros"
        ],
    ) -> typing_extensions.Literal["cpc_bid_ceiling_micros"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_enhanced_cpc_enabled", b"_enhanced_cpc_enabled"
        ],
    ) -> typing_extensions.Literal["enhanced_cpc_enabled"]: ...

global___PercentCpc = PercentCpc



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v5.proto.resources.ad_group_ad_label_pb2
import grpc

from .ad_group_ad_label_service_pb2 import *

class AdGroupAdLabelServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetAdGroupAdLabel(
        self,
        request: global___GetAdGroupAdLabelRequest,
    ) -> google.ads.google_ads.v5.proto.resources.ad_group_ad_label_pb2.AdGroupAdLabel: ...
    def MutateAdGroupAdLabels(
        self,
        request: global___MutateAdGroupAdLabelsRequest,
    ) -> global___MutateAdGroupAdLabelsResponse: ...

class AdGroupAdLabelServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetAdGroupAdLabel(
        self,
        request: global___GetAdGroupAdLabelRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v5.proto.resources.ad_group_ad_label_pb2.AdGroupAdLabel: ...
    @abc.abstractmethod
    def MutateAdGroupAdLabels(
        self,
        request: global___MutateAdGroupAdLabelsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateAdGroupAdLabelsResponse: ...

def add_AdGroupAdLabelServiceServicer_to_server(
    servicer: AdGroupAdLabelServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GenderTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _GenderType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[GenderType.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = GenderTypeEnum.GenderType.V(0)
        UNKNOWN = GenderTypeEnum.GenderType.V(1)
        MALE = GenderTypeEnum.GenderType.V(10)
        FEMALE = GenderTypeEnum.GenderType.V(11)
        UNDETERMINED = GenderTypeEnum.GenderType.V(20)
    class GenderType(metaclass=_GenderType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = GenderTypeEnum.GenderType.V(0)
    UNKNOWN = GenderTypeEnum.GenderType.V(1)
    MALE = GenderTypeEnum.GenderType.V(10)
    FEMALE = GenderTypeEnum.GenderType.V(11)
    UNDETERMINED = GenderTypeEnum.GenderType.V(20)
    def __init__(
        self,
    ) -> None: ...

global___GenderTypeEnum = GenderTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.keyword_plan_ad_group_pb2
import grpc

from .keyword_plan_ad_group_service_pb2 import *

class KeywordPlanAdGroupServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetKeywordPlanAdGroup(
        self,
        request: global___GetKeywordPlanAdGroupRequest,
    ) -> google.ads.google_ads.v6.proto.resources.keyword_plan_ad_group_pb2.KeywordPlanAdGroup: ...
    def MutateKeywordPlanAdGroups(
        self,
        request: global___MutateKeywordPlanAdGroupsRequest,
    ) -> global___MutateKeywordPlanAdGroupsResponse: ...

class KeywordPlanAdGroupServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetKeywordPlanAdGroup(
        self,
        request: global___GetKeywordPlanAdGroupRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.keyword_plan_ad_group_pb2.KeywordPlanAdGroup: ...
    @abc.abstractmethod
    def MutateKeywordPlanAdGroups(
        self,
        request: global___MutateKeywordPlanAdGroupsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateKeywordPlanAdGroupsResponse: ...

def add_KeywordPlanAdGroupServiceServicer_to_server(
    servicer: KeywordPlanAdGroupServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ConversionUploadErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ConversionUploadError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ConversionUploadError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ConversionUploadErrorEnum.ConversionUploadError.V(0)
        UNKNOWN = ConversionUploadErrorEnum.ConversionUploadError.V(1)
        TOO_MANY_CONVERSIONS_IN_REQUEST = (
            ConversionUploadErrorEnum.ConversionUploadError.V(2)
        )
        UNPARSEABLE_GCLID = ConversionUploadErrorEnum.ConversionUploadError.V(3)
        CONVERSION_PRECEDES_GCLID = ConversionUploadErrorEnum.ConversionUploadError.V(4)
        EXPIRED_GCLID = ConversionUploadErrorEnum.ConversionUploadError.V(5)
        TOO_RECENT_GCLID = ConversionUploadErrorEnum.ConversionUploadError.V(6)
        GCLID_NOT_FOUND = ConversionUploadErrorEnum.ConversionUploadError.V(7)
        UNAUTHORIZED_CUSTOMER = ConversionUploadErrorEnum.ConversionUploadError.V(8)
        INVALID_CONVERSION_ACTION = ConversionUploadErrorEnum.ConversionUploadError.V(9)
        TOO_RECENT_CONVERSION_ACTION = (
            ConversionUploadErrorEnum.ConversionUploadError.V(10)
        )
        CONVERSION_TRACKING_NOT_ENABLED_AT_IMPRESSION_TIME = (
            ConversionUploadErrorEnum.ConversionUploadError.V(11)
        )
        EXTERNAL_ATTRIBUTION_DATA_SET_FOR_NON_EXTERNALLY_ATTRIBUTED_CONVERSION_ACTION = ConversionUploadErrorEnum.ConversionUploadError.V(
            12
        )
        EXTERNAL_ATTRIBUTION_DATA_NOT_SET_FOR_EXTERNALLY_ATTRIBUTED_CONVERSION_ACTION = ConversionUploadErrorEnum.ConversionUploadError.V(
            13
        )
        ORDER_ID_NOT_PERMITTED_FOR_EXTERNALLY_ATTRIBUTED_CONVERSION_ACTION = (
            ConversionUploadErrorEnum.ConversionUploadError.V(14)
        )
        ORDER_ID_ALREADY_IN_USE = ConversionUploadErrorEnum.ConversionUploadError.V(15)
        DUPLICATE_ORDER_ID = ConversionUploadErrorEnum.ConversionUploadError.V(16)
        TOO_RECENT_CALL = ConversionUploadErrorEnum.ConversionUploadError.V(17)
        EXPIRED_CALL = ConversionUploadErrorEnum.ConversionUploadError.V(18)
        CALL_NOT_FOUND = ConversionUploadErrorEnum.ConversionUploadError.V(19)
        CONVERSION_PRECEDES_CALL = ConversionUploadErrorEnum.ConversionUploadError.V(20)
        CONVERSION_TRACKING_NOT_ENABLED_AT_CALL_TIME = (
            ConversionUploadErrorEnum.ConversionUploadError.V(21)
        )
        UNPARSEABLE_CALLERS_PHONE_NUMBER = (
            ConversionUploadErrorEnum.ConversionUploadError.V(22)
        )
    class ConversionUploadError(metaclass=_ConversionUploadError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ConversionUploadErrorEnum.ConversionUploadError.V(0)
    UNKNOWN = ConversionUploadErrorEnum.ConversionUploadError.V(1)
    TOO_MANY_CONVERSIONS_IN_REQUEST = ConversionUploadErrorEnum.ConversionUploadError.V(
        2
    )
    UNPARSEABLE_GCLID = ConversionUploadErrorEnum.ConversionUploadError.V(3)
    CONVERSION_PRECEDES_GCLID = ConversionUploadErrorEnum.ConversionUploadError.V(4)
    EXPIRED_GCLID = ConversionUploadErrorEnum.ConversionUploadError.V(5)
    TOO_RECENT_GCLID = ConversionUploadErrorEnum.ConversionUploadError.V(6)
    GCLID_NOT_FOUND = ConversionUploadErrorEnum.ConversionUploadError.V(7)
    UNAUTHORIZED_CUSTOMER = ConversionUploadErrorEnum.ConversionUploadError.V(8)
    INVALID_CONVERSION_ACTION = ConversionUploadErrorEnum.ConversionUploadError.V(9)
    TOO_RECENT_CONVERSION_ACTION = ConversionUploadErrorEnum.ConversionUploadError.V(10)
    CONVERSION_TRACKING_NOT_ENABLED_AT_IMPRESSION_TIME = (
        ConversionUploadErrorEnum.ConversionUploadError.V(11)
    )
    EXTERNAL_ATTRIBUTION_DATA_SET_FOR_NON_EXTERNALLY_ATTRIBUTED_CONVERSION_ACTION = (
        ConversionUploadErrorEnum.ConversionUploadError.V(12)
    )
    EXTERNAL_ATTRIBUTION_DATA_NOT_SET_FOR_EXTERNALLY_ATTRIBUTED_CONVERSION_ACTION = (
        ConversionUploadErrorEnum.ConversionUploadError.V(13)
    )
    ORDER_ID_NOT_PERMITTED_FOR_EXTERNALLY_ATTRIBUTED_CONVERSION_ACTION = (
        ConversionUploadErrorEnum.ConversionUploadError.V(14)
    )
    ORDER_ID_ALREADY_IN_USE = ConversionUploadErrorEnum.ConversionUploadError.V(15)
    DUPLICATE_ORDER_ID = ConversionUploadErrorEnum.ConversionUploadError.V(16)
    TOO_RECENT_CALL = ConversionUploadErrorEnum.ConversionUploadError.V(17)
    EXPIRED_CALL = ConversionUploadErrorEnum.ConversionUploadError.V(18)
    CALL_NOT_FOUND = ConversionUploadErrorEnum.ConversionUploadError.V(19)
    CONVERSION_PRECEDES_CALL = ConversionUploadErrorEnum.ConversionUploadError.V(20)
    CONVERSION_TRACKING_NOT_ENABLED_AT_CALL_TIME = (
        ConversionUploadErrorEnum.ConversionUploadError.V(21)
    )
    UNPARSEABLE_CALLERS_PHONE_NUMBER = (
        ConversionUploadErrorEnum.ConversionUploadError.V(22)
    )
    def __init__(
        self,
    ) -> None: ...

global___ConversionUploadErrorEnum = ConversionUploadErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ServedAssetFieldTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ServedAssetFieldType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ServedAssetFieldType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ServedAssetFieldTypeEnum.ServedAssetFieldType.V(0)
        UNKNOWN = ServedAssetFieldTypeEnum.ServedAssetFieldType.V(1)
        HEADLINE_1 = ServedAssetFieldTypeEnum.ServedAssetFieldType.V(2)
        HEADLINE_2 = ServedAssetFieldTypeEnum.ServedAssetFieldType.V(3)
        HEADLINE_3 = ServedAssetFieldTypeEnum.ServedAssetFieldType.V(4)
        DESCRIPTION_1 = ServedAssetFieldTypeEnum.ServedAssetFieldType.V(5)
        DESCRIPTION_2 = ServedAssetFieldTypeEnum.ServedAssetFieldType.V(6)
    class ServedAssetFieldType(metaclass=_ServedAssetFieldType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ServedAssetFieldTypeEnum.ServedAssetFieldType.V(0)
    UNKNOWN = ServedAssetFieldTypeEnum.ServedAssetFieldType.V(1)
    HEADLINE_1 = ServedAssetFieldTypeEnum.ServedAssetFieldType.V(2)
    HEADLINE_2 = ServedAssetFieldTypeEnum.ServedAssetFieldType.V(3)
    HEADLINE_3 = ServedAssetFieldTypeEnum.ServedAssetFieldType.V(4)
    DESCRIPTION_1 = ServedAssetFieldTypeEnum.ServedAssetFieldType.V(5)
    DESCRIPTION_2 = ServedAssetFieldTypeEnum.ServedAssetFieldType.V(6)
    def __init__(
        self,
    ) -> None: ...

global___ServedAssetFieldTypeEnum = ServedAssetFieldTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.enums.change_client_type_pb2
import google.ads.google_ads.v6.proto.enums.change_event_resource_type_pb2
import google.ads.google_ads.v6.proto.enums.resource_change_operation_pb2
import google.ads.google_ads.v6.proto.resources.ad_group_ad_pb2
import google.ads.google_ads.v6.proto.resources.ad_group_bid_modifier_pb2
import google.ads.google_ads.v6.proto.resources.ad_group_criterion_pb2
import google.ads.google_ads.v6.proto.resources.ad_group_feed_pb2
import google.ads.google_ads.v6.proto.resources.ad_group_pb2
import google.ads.google_ads.v6.proto.resources.ad_pb2
import google.ads.google_ads.v6.proto.resources.campaign_budget_pb2
import google.ads.google_ads.v6.proto.resources.campaign_criterion_pb2
import google.ads.google_ads.v6.proto.resources.campaign_feed_pb2
import google.ads.google_ads.v6.proto.resources.campaign_pb2
import google.ads.google_ads.v6.proto.resources.feed_item_pb2
import google.ads.google_ads.v6.proto.resources.feed_pb2
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ChangeEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class ChangedResource(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        AD_FIELD_NUMBER: builtins.int
        AD_GROUP_FIELD_NUMBER: builtins.int
        AD_GROUP_CRITERION_FIELD_NUMBER: builtins.int
        CAMPAIGN_FIELD_NUMBER: builtins.int
        CAMPAIGN_BUDGET_FIELD_NUMBER: builtins.int
        AD_GROUP_BID_MODIFIER_FIELD_NUMBER: builtins.int
        CAMPAIGN_CRITERION_FIELD_NUMBER: builtins.int
        FEED_FIELD_NUMBER: builtins.int
        FEED_ITEM_FIELD_NUMBER: builtins.int
        CAMPAIGN_FEED_FIELD_NUMBER: builtins.int
        AD_GROUP_FEED_FIELD_NUMBER: builtins.int
        AD_GROUP_AD_FIELD_NUMBER: builtins.int
        @property
        def ad(self) -> google.ads.google_ads.v6.proto.resources.ad_pb2.Ad: ...
        @property
        def ad_group(
            self,
        ) -> google.ads.google_ads.v6.proto.resources.ad_group_pb2.AdGroup: ...
        @property
        def ad_group_criterion(
            self,
        ) -> google.ads.google_ads.v6.proto.resources.ad_group_criterion_pb2.AdGroupCriterion: ...
        @property
        def campaign(
            self,
        ) -> google.ads.google_ads.v6.proto.resources.campaign_pb2.Campaign: ...
        @property
        def campaign_budget(
            self,
        ) -> google.ads.google_ads.v6.proto.resources.campaign_budget_pb2.CampaignBudget: ...
        @property
        def ad_group_bid_modifier(
            self,
        ) -> google.ads.google_ads.v6.proto.resources.ad_group_bid_modifier_pb2.AdGroupBidModifier: ...
        @property
        def campaign_criterion(
            self,
        ) -> google.ads.google_ads.v6.proto.resources.campaign_criterion_pb2.CampaignCriterion: ...
        @property
        def feed(self) -> google.ads.google_ads.v6.proto.resources.feed_pb2.Feed: ...
        @property
        def feed_item(
            self,
        ) -> google.ads.google_ads.v6.proto.resources.feed_item_pb2.FeedItem: ...
        @property
        def campaign_feed(
            self,
        ) -> google.ads.google_ads.v6.proto.resources.campaign_feed_pb2.CampaignFeed: ...
        @property
        def ad_group_feed(
            self,
        ) -> google.ads.google_ads.v6.proto.resources.ad_group_feed_pb2.AdGroupFeed: ...
        @property
        def ad_group_ad(
            self,
        ) -> google.ads.google_ads.v6.proto.resources.ad_group_ad_pb2.AdGroupAd: ...
        def __init__(
            self,
            *,
            ad: typing.Optional[
                google.ads.google_ads.v6.proto.resources.ad_pb2.Ad
            ] = ...,
            ad_group: typing.Optional[
                google.ads.google_ads.v6.proto.resources.ad_group_pb2.AdGroup
            ] = ...,
            ad_group_criterion: typing.Optional[
                google.ads.google_ads.v6.proto.resources.ad_group_criterion_pb2.AdGroupCriterion
            ] = ...,
            campaign: typing.Optional[
                google.ads.google_ads.v6.proto.resources.campaign_pb2.Campaign
            ] = ...,
            campaign_budget: typing.Optional[
                google.ads.google_ads.v6.proto.resources.campaign_budget_pb2.CampaignBudget
            ] = ...,
            ad_group_bid_modifier: typing.Optional[
                google.ads.google_ads.v6.proto.resources.ad_group_bid_modifier_pb2.AdGroupBidModifier
            ] = ...,
            campaign_criterion: typing.Optional[
                google.ads.google_ads.v6.proto.resources.campaign_criterion_pb2.CampaignCriterion
            ] = ...,
            feed: typing.Optional[
                google.ads.google_ads.v6.proto.resources.feed_pb2.Feed
            ] = ...,
            feed_item: typing.Optional[
                google.ads.google_ads.v6.proto.resources.feed_item_pb2.FeedItem
            ] = ...,
            campaign_feed: typing.Optional[
                google.ads.google_ads.v6.proto.resources.campaign_feed_pb2.CampaignFeed
            ] = ...,
            ad_group_feed: typing.Optional[
                google.ads.google_ads.v6.proto.resources.ad_group_feed_pb2.AdGroupFeed
            ] = ...,
            ad_group_ad: typing.Optional[
                google.ads.google_ads.v6.proto.resources.ad_group_ad_pb2.AdGroupAd
            ] = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions.Literal[
                "ad",
                b"ad",
                "ad_group",
                b"ad_group",
                "ad_group_ad",
                b"ad_group_ad",
                "ad_group_bid_modifier",
                b"ad_group_bid_modifier",
                "ad_group_criterion",
                b"ad_group_criterion",
                "ad_group_feed",
                b"ad_group_feed",
                "campaign",
                b"campaign",
                "campaign_budget",
                b"campaign_budget",
                "campaign_criterion",
                b"campaign_criterion",
                "campaign_feed",
                b"campaign_feed",
                "feed",
                b"feed",
                "feed_item",
                b"feed_item",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "ad",
                b"ad",
                "ad_group",
                b"ad_group",
                "ad_group_ad",
                b"ad_group_ad",
                "ad_group_bid_modifier",
                b"ad_group_bid_modifier",
                "ad_group_criterion",
                b"ad_group_criterion",
                "ad_group_feed",
                b"ad_group_feed",
                "campaign",
                b"campaign",
                "campaign_budget",
                b"campaign_budget",
                "campaign_criterion",
                b"campaign_criterion",
                "campaign_feed",
                b"campaign_feed",
                "feed",
                b"feed",
                "feed_item",
                b"feed_item",
            ],
        ) -> None: ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    CHANGE_DATE_TIME_FIELD_NUMBER: builtins.int
    CHANGE_RESOURCE_TYPE_FIELD_NUMBER: builtins.int
    CHANGE_RESOURCE_NAME_FIELD_NUMBER: builtins.int
    CLIENT_TYPE_FIELD_NUMBER: builtins.int
    USER_EMAIL_FIELD_NUMBER: builtins.int
    OLD_RESOURCE_FIELD_NUMBER: builtins.int
    NEW_RESOURCE_FIELD_NUMBER: builtins.int
    RESOURCE_CHANGE_OPERATION_FIELD_NUMBER: builtins.int
    CHANGED_FIELDS_FIELD_NUMBER: builtins.int
    CAMPAIGN_FIELD_NUMBER: builtins.int
    AD_GROUP_FIELD_NUMBER: builtins.int
    FEED_FIELD_NUMBER: builtins.int
    FEED_ITEM_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    change_date_time: typing.Text = ...
    change_resource_type: google.ads.google_ads.v6.proto.enums.change_event_resource_type_pb2.ChangeEventResourceTypeEnum.ChangeEventResourceType.V = (
        ...
    )
    change_resource_name: typing.Text = ...
    client_type: google.ads.google_ads.v6.proto.enums.change_client_type_pb2.ChangeClientTypeEnum.ChangeClientType.V = (
        ...
    )
    user_email: typing.Text = ...
    resource_change_operation: google.ads.google_ads.v6.proto.enums.resource_change_operation_pb2.ResourceChangeOperationEnum.ResourceChangeOperation.V = (
        ...
    )
    campaign: typing.Text = ...
    ad_group: typing.Text = ...
    feed: typing.Text = ...
    feed_item: typing.Text = ...
    @property
    def old_resource(self) -> global___ChangeEvent.ChangedResource: ...
    @property
    def new_resource(self) -> global___ChangeEvent.ChangedResource: ...
    @property
    def changed_fields(self) -> google.protobuf.field_mask_pb2.FieldMask: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        change_date_time: typing.Text = ...,
        change_resource_type: google.ads.google_ads.v6.proto.enums.change_event_resource_type_pb2.ChangeEventResourceTypeEnum.ChangeEventResourceType.V = ...,
        change_resource_name: typing.Text = ...,
        client_type: google.ads.google_ads.v6.proto.enums.change_client_type_pb2.ChangeClientTypeEnum.ChangeClientType.V = ...,
        user_email: typing.Text = ...,
        old_resource: typing.Optional[global___ChangeEvent.ChangedResource] = ...,
        new_resource: typing.Optional[global___ChangeEvent.ChangedResource] = ...,
        resource_change_operation: google.ads.google_ads.v6.proto.enums.resource_change_operation_pb2.ResourceChangeOperationEnum.ResourceChangeOperation.V = ...,
        changed_fields: typing.Optional[google.protobuf.field_mask_pb2.FieldMask] = ...,
        campaign: typing.Text = ...,
        ad_group: typing.Text = ...,
        feed: typing.Text = ...,
        feed_item: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "changed_fields",
            b"changed_fields",
            "new_resource",
            b"new_resource",
            "old_resource",
            b"old_resource",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "ad_group",
            b"ad_group",
            "campaign",
            b"campaign",
            "change_date_time",
            b"change_date_time",
            "change_resource_name",
            b"change_resource_name",
            "change_resource_type",
            b"change_resource_type",
            "changed_fields",
            b"changed_fields",
            "client_type",
            b"client_type",
            "feed",
            b"feed",
            "feed_item",
            b"feed_item",
            "new_resource",
            b"new_resource",
            "old_resource",
            b"old_resource",
            "resource_change_operation",
            b"resource_change_operation",
            "resource_name",
            b"resource_name",
            "user_email",
            b"user_email",
        ],
    ) -> None: ...

global___ChangeEvent = ChangeEvent



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.offline_user_data_job_pb2
import google.longrunning.operations_pb2
import grpc

from .offline_user_data_job_service_pb2 import *

class OfflineUserDataJobServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def CreateOfflineUserDataJob(
        self,
        request: global___CreateOfflineUserDataJobRequest,
    ) -> global___CreateOfflineUserDataJobResponse: ...
    def GetOfflineUserDataJob(
        self,
        request: global___GetOfflineUserDataJobRequest,
    ) -> google.ads.google_ads.v6.proto.resources.offline_user_data_job_pb2.OfflineUserDataJob: ...
    def AddOfflineUserDataJobOperations(
        self,
        request: global___AddOfflineUserDataJobOperationsRequest,
    ) -> global___AddOfflineUserDataJobOperationsResponse: ...
    def RunOfflineUserDataJob(
        self,
        request: global___RunOfflineUserDataJobRequest,
    ) -> google.longrunning.operations_pb2.Operation: ...

class OfflineUserDataJobServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def CreateOfflineUserDataJob(
        self,
        request: global___CreateOfflineUserDataJobRequest,
        context: grpc.ServicerContext,
    ) -> global___CreateOfflineUserDataJobResponse: ...
    @abc.abstractmethod
    def GetOfflineUserDataJob(
        self,
        request: global___GetOfflineUserDataJobRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.offline_user_data_job_pb2.OfflineUserDataJob: ...
    @abc.abstractmethod
    def AddOfflineUserDataJobOperations(
        self,
        request: global___AddOfflineUserDataJobOperationsRequest,
        context: grpc.ServicerContext,
    ) -> global___AddOfflineUserDataJobOperationsResponse: ...
    @abc.abstractmethod
    def RunOfflineUserDataJob(
        self,
        request: global___RunOfflineUserDataJobRequest,
        context: grpc.ServicerContext,
    ) -> google.longrunning.operations_pb2.Operation: ...

def add_OfflineUserDataJobServiceServicer_to_server(
    servicer: OfflineUserDataJobServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.feed_item_pb2
import grpc

from .feed_item_service_pb2 import *

class FeedItemServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetFeedItem(
        self,
        request: global___GetFeedItemRequest,
    ) -> google.ads.google_ads.v6.proto.resources.feed_item_pb2.FeedItem: ...
    def MutateFeedItems(
        self,
        request: global___MutateFeedItemsRequest,
    ) -> global___MutateFeedItemsResponse: ...

class FeedItemServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetFeedItem(
        self,
        request: global___GetFeedItemRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.feed_item_pb2.FeedItem: ...
    @abc.abstractmethod
    def MutateFeedItems(
        self,
        request: global___MutateFeedItemsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateFeedItemsResponse: ...

def add_FeedItemServiceServicer_to_server(
    servicer: FeedItemServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MediaTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _MediaType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MediaType.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = MediaTypeEnum.MediaType.V(0)
        UNKNOWN = MediaTypeEnum.MediaType.V(1)
        IMAGE = MediaTypeEnum.MediaType.V(2)
        ICON = MediaTypeEnum.MediaType.V(3)
        MEDIA_BUNDLE = MediaTypeEnum.MediaType.V(4)
        AUDIO = MediaTypeEnum.MediaType.V(5)
        VIDEO = MediaTypeEnum.MediaType.V(6)
        DYNAMIC_IMAGE = MediaTypeEnum.MediaType.V(7)
    class MediaType(metaclass=_MediaType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = MediaTypeEnum.MediaType.V(0)
    UNKNOWN = MediaTypeEnum.MediaType.V(1)
    IMAGE = MediaTypeEnum.MediaType.V(2)
    ICON = MediaTypeEnum.MediaType.V(3)
    MEDIA_BUNDLE = MediaTypeEnum.MediaType.V(4)
    AUDIO = MediaTypeEnum.MediaType.V(5)
    VIDEO = MediaTypeEnum.MediaType.V(6)
    DYNAMIC_IMAGE = MediaTypeEnum.MediaType.V(7)
    def __init__(
        self,
    ) -> None: ...

global___MediaTypeEnum = MediaTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class SharedSetErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _SharedSetError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[SharedSetError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = SharedSetErrorEnum.SharedSetError.V(0)
        UNKNOWN = SharedSetErrorEnum.SharedSetError.V(1)
        CUSTOMER_CANNOT_CREATE_SHARED_SET_OF_THIS_TYPE = (
            SharedSetErrorEnum.SharedSetError.V(2)
        )
        DUPLICATE_NAME = SharedSetErrorEnum.SharedSetError.V(3)
        SHARED_SET_REMOVED = SharedSetErrorEnum.SharedSetError.V(4)
        SHARED_SET_IN_USE = SharedSetErrorEnum.SharedSetError.V(5)
    class SharedSetError(metaclass=_SharedSetError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = SharedSetErrorEnum.SharedSetError.V(0)
    UNKNOWN = SharedSetErrorEnum.SharedSetError.V(1)
    CUSTOMER_CANNOT_CREATE_SHARED_SET_OF_THIS_TYPE = (
        SharedSetErrorEnum.SharedSetError.V(2)
    )
    DUPLICATE_NAME = SharedSetErrorEnum.SharedSetError.V(3)
    SHARED_SET_REMOVED = SharedSetErrorEnum.SharedSetError.V(4)
    SHARED_SET_IN_USE = SharedSetErrorEnum.SharedSetError.V(5)
    def __init__(
        self,
    ) -> None: ...

global___SharedSetErrorEnum = SharedSetErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class FunctionErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _FunctionError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[FunctionError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = FunctionErrorEnum.FunctionError.V(0)
        UNKNOWN = FunctionErrorEnum.FunctionError.V(1)
        INVALID_FUNCTION_FORMAT = FunctionErrorEnum.FunctionError.V(2)
        DATA_TYPE_MISMATCH = FunctionErrorEnum.FunctionError.V(3)
        INVALID_CONJUNCTION_OPERANDS = FunctionErrorEnum.FunctionError.V(4)
        INVALID_NUMBER_OF_OPERANDS = FunctionErrorEnum.FunctionError.V(5)
        INVALID_OPERAND_TYPE = FunctionErrorEnum.FunctionError.V(6)
        INVALID_OPERATOR = FunctionErrorEnum.FunctionError.V(7)
        INVALID_REQUEST_CONTEXT_TYPE = FunctionErrorEnum.FunctionError.V(8)
        INVALID_FUNCTION_FOR_CALL_PLACEHOLDER = FunctionErrorEnum.FunctionError.V(9)
        INVALID_FUNCTION_FOR_PLACEHOLDER = FunctionErrorEnum.FunctionError.V(10)
        INVALID_OPERAND = FunctionErrorEnum.FunctionError.V(11)
        MISSING_CONSTANT_OPERAND_VALUE = FunctionErrorEnum.FunctionError.V(12)
        INVALID_CONSTANT_OPERAND_VALUE = FunctionErrorEnum.FunctionError.V(13)
        INVALID_NESTING = FunctionErrorEnum.FunctionError.V(14)
        MULTIPLE_FEED_IDS_NOT_SUPPORTED = FunctionErrorEnum.FunctionError.V(15)
        INVALID_FUNCTION_FOR_FEED_WITH_FIXED_SCHEMA = FunctionErrorEnum.FunctionError.V(
            16
        )
        INVALID_ATTRIBUTE_NAME = FunctionErrorEnum.FunctionError.V(17)
    class FunctionError(metaclass=_FunctionError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = FunctionErrorEnum.FunctionError.V(0)
    UNKNOWN = FunctionErrorEnum.FunctionError.V(1)
    INVALID_FUNCTION_FORMAT = FunctionErrorEnum.FunctionError.V(2)
    DATA_TYPE_MISMATCH = FunctionErrorEnum.FunctionError.V(3)
    INVALID_CONJUNCTION_OPERANDS = FunctionErrorEnum.FunctionError.V(4)
    INVALID_NUMBER_OF_OPERANDS = FunctionErrorEnum.FunctionError.V(5)
    INVALID_OPERAND_TYPE = FunctionErrorEnum.FunctionError.V(6)
    INVALID_OPERATOR = FunctionErrorEnum.FunctionError.V(7)
    INVALID_REQUEST_CONTEXT_TYPE = FunctionErrorEnum.FunctionError.V(8)
    INVALID_FUNCTION_FOR_CALL_PLACEHOLDER = FunctionErrorEnum.FunctionError.V(9)
    INVALID_FUNCTION_FOR_PLACEHOLDER = FunctionErrorEnum.FunctionError.V(10)
    INVALID_OPERAND = FunctionErrorEnum.FunctionError.V(11)
    MISSING_CONSTANT_OPERAND_VALUE = FunctionErrorEnum.FunctionError.V(12)
    INVALID_CONSTANT_OPERAND_VALUE = FunctionErrorEnum.FunctionError.V(13)
    INVALID_NESTING = FunctionErrorEnum.FunctionError.V(14)
    MULTIPLE_FEED_IDS_NOT_SUPPORTED = FunctionErrorEnum.FunctionError.V(15)
    INVALID_FUNCTION_FOR_FEED_WITH_FIXED_SCHEMA = FunctionErrorEnum.FunctionError.V(16)
    INVALID_ATTRIBUTE_NAME = FunctionErrorEnum.FunctionError.V(17)
    def __init__(
        self,
    ) -> None: ...

global___FunctionErrorEnum = FunctionErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AttributionModelEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AttributionModel(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AttributionModel.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AttributionModelEnum.AttributionModel.V(0)
        UNKNOWN = AttributionModelEnum.AttributionModel.V(1)
        EXTERNAL = AttributionModelEnum.AttributionModel.V(100)
        GOOGLE_ADS_LAST_CLICK = AttributionModelEnum.AttributionModel.V(101)
        GOOGLE_SEARCH_ATTRIBUTION_FIRST_CLICK = AttributionModelEnum.AttributionModel.V(
            102
        )
        GOOGLE_SEARCH_ATTRIBUTION_LINEAR = AttributionModelEnum.AttributionModel.V(103)
        GOOGLE_SEARCH_ATTRIBUTION_TIME_DECAY = AttributionModelEnum.AttributionModel.V(
            104
        )
        GOOGLE_SEARCH_ATTRIBUTION_POSITION_BASED = (
            AttributionModelEnum.AttributionModel.V(105)
        )
        GOOGLE_SEARCH_ATTRIBUTION_DATA_DRIVEN = AttributionModelEnum.AttributionModel.V(
            106
        )
    class AttributionModel(metaclass=_AttributionModel):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AttributionModelEnum.AttributionModel.V(0)
    UNKNOWN = AttributionModelEnum.AttributionModel.V(1)
    EXTERNAL = AttributionModelEnum.AttributionModel.V(100)
    GOOGLE_ADS_LAST_CLICK = AttributionModelEnum.AttributionModel.V(101)
    GOOGLE_SEARCH_ATTRIBUTION_FIRST_CLICK = AttributionModelEnum.AttributionModel.V(102)
    GOOGLE_SEARCH_ATTRIBUTION_LINEAR = AttributionModelEnum.AttributionModel.V(103)
    GOOGLE_SEARCH_ATTRIBUTION_TIME_DECAY = AttributionModelEnum.AttributionModel.V(104)
    GOOGLE_SEARCH_ATTRIBUTION_POSITION_BASED = AttributionModelEnum.AttributionModel.V(
        105
    )
    GOOGLE_SEARCH_ATTRIBUTION_DATA_DRIVEN = AttributionModelEnum.AttributionModel.V(106)
    def __init__(
        self,
    ) -> None: ...

global___AttributionModelEnum = AttributionModelEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.resources.campaign_asset_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.rpc.status_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GetCampaignAssetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["resource_name", b"resource_name"]
    ) -> None: ...

global___GetCampaignAssetRequest = GetCampaignAssetRequest

class MutateCampaignAssetsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CUSTOMER_ID_FIELD_NUMBER: builtins.int
    OPERATIONS_FIELD_NUMBER: builtins.int
    PARTIAL_FAILURE_FIELD_NUMBER: builtins.int
    VALIDATE_ONLY_FIELD_NUMBER: builtins.int
    customer_id: typing.Text = ...
    partial_failure: builtins.bool = ...
    validate_only: builtins.bool = ...
    @property
    def operations(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___CampaignAssetOperation
    ]: ...
    def __init__(
        self,
        *,
        customer_id: typing.Text = ...,
        operations: typing.Optional[
            typing.Iterable[global___CampaignAssetOperation]
        ] = ...,
        partial_failure: builtins.bool = ...,
        validate_only: builtins.bool = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "customer_id",
            b"customer_id",
            "operations",
            b"operations",
            "partial_failure",
            b"partial_failure",
            "validate_only",
            b"validate_only",
        ],
    ) -> None: ...

global___MutateCampaignAssetsRequest = MutateCampaignAssetsRequest

class CampaignAssetOperation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CREATE_FIELD_NUMBER: builtins.int
    REMOVE_FIELD_NUMBER: builtins.int
    remove: typing.Text = ...
    @property
    def create(
        self,
    ) -> google.ads.google_ads.v6.proto.resources.campaign_asset_pb2.CampaignAsset: ...
    def __init__(
        self,
        *,
        create: typing.Optional[
            google.ads.google_ads.v6.proto.resources.campaign_asset_pb2.CampaignAsset
        ] = ...,
        remove: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "create", b"create", "operation", b"operation", "remove", b"remove"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "create", b"create", "operation", b"operation", "remove", b"remove"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["operation", b"operation"]
    ) -> typing_extensions.Literal["create", "remove"]: ...

global___CampaignAssetOperation = CampaignAssetOperation

class MutateCampaignAssetsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PARTIAL_FAILURE_ERROR_FIELD_NUMBER: builtins.int
    RESULTS_FIELD_NUMBER: builtins.int
    @property
    def partial_failure_error(self) -> google.rpc.status_pb2.Status: ...
    @property
    def results(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___MutateCampaignAssetResult
    ]: ...
    def __init__(
        self,
        *,
        partial_failure_error: typing.Optional[google.rpc.status_pb2.Status] = ...,
        results: typing.Optional[
            typing.Iterable[global___MutateCampaignAssetResult]
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "partial_failure_error", b"partial_failure_error"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "partial_failure_error", b"partial_failure_error", "results", b"results"
        ],
    ) -> None: ...

global___MutateCampaignAssetsResponse = MutateCampaignAssetsResponse

class MutateCampaignAssetResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["resource_name", b"resource_name"]
    ) -> None: ...

global___MutateCampaignAssetResult = MutateCampaignAssetResult
